/******************************************************************************
* C Include: Field                                                            
*                                                                             
* File:                                                                       
*    field.h                                                                  
*                                                                             
* Description:                                                                
*    Include file for the Field functions.                                    
*                                                                             
* History:                                                                    
*    Created    : 15-JUN-93 by J. Doggett,                                    
*       for the Association of Universities for Research in Astronomy, Inc.   
*          at the Space Telescope Science Institute,                          
*       to facilitate the accessing of data from the CD-ROM set of the        
*          Digitized Sky Survey.                                              
*    Delivered  : 01-MAR-94 by J. Doggett,                                    
*       GetImage Version 1.0.                                                 
*                                                                             
*    Updated    : 28-SEP-95 by J. Doggett,                                    
*       Increased limit of field name size 20 characters.                     
*    Redelivered: 01-AUG-96 by J. Doggett,                                    
*       GetImage Version 1.3.                                                 
*                                                                             
* Copyright (c) 1993-1996, Association of Universities for Research in        
* Astronomy, Inc.  All Rights Reserved.                                       
* Produced under National Aeronautics and Space Administration grant          
* NAG W-2166.                                                                 
******************************************************************************/
#ifndef __FIELD__
#define __FIELD__

#include <stdio.h>

#include "astronmy.h"
#include "config.h"
#include "generic.h"

/******************
* Field constants *
******************/
#if (defined (__UNIX)) || (defined (__VMS))
# define FIELD_NAME_MAX_LENGTH 20
#else
# define FIELD_NAME_MAX_LENGTH 4
#endif

/***************************
* Field derived data types *
****************************/
struct Field_Info /* Information about a user requested field */
{
   char   Name[FIELD_NAME_MAX_LENGTH + 1]
                    ; /* characters; must be valid for a filename */
   double Center_RA ; /* In radians                               */
   double Center_Dec; /*     ""                                   */
   double Width     ; /* In arcminutes                            */
   double Height    ; /*      ""                                  */
};
typedef struct Field_Info * FIELD;

/******************************
* Field functions' prototypes *
******************************/
int   Compare_Fields (/* FIELD    Field_1   ,
                         FIELD    Field_2    */);

/* *** Field Include File ***                                             2 */


FIELD Create_Field   (/* STRING   Name      ,
                         double   Center_RA ,
                         double   Center_Dec,
                         double   Width     ,
                         double   Height     */);

void  Delete_Field   (/* FIELD    Field      */);

FIELD Read_Field_Info(/* EQUINOX  Equinox   ,
                         FILE    *InputFile  */);

#endif
